# Test cases for Lab 7 - Fall 2023
#-------------------------------------------------------------------------------------------
import autotester_base
from autotester_base import Lit, opts

def testall(start=None, mode='brief', clear=True):
   autotester_base.test_target_list(_target_list, _test_cases, start, mode, clear)

def test(fun_or_name, cases=None, mode=None, alias=None, input=None):
   autotester_base.test_single_function(fun_or_name, cases, mode, alias, input, _test_cases)

def vtest(fun_or_name, cases=None, alias=None, input=None):
   autotester_base.test_single_function(fun_or_name, cases, 'verbose', alias, input, _test_cases)

#-------------------------------------------------------------------------------------------

_target_list = [
   'charType',
   'firstVowelPosition',
   'translateWord',
   'translateLine',
   opts('translateFile', cases=1),
   # capitalization/punctuation version of translateWord:
   'translateWord2',
   opts('translateFile', cases=2),
   opts('spell', mode='verbose'),
   ]

#-------------------------------------------------------------------------------------------

_test_cases = {

   'charType':{
      1: ('', ('a',), 'vowel'),
      2: ('', ('E',), 'vowel'),
      3: ('', ('b',), 'consonant'),
      4: ('', ('y',), 'consonant'),
      5: ('', ('Z',), 'consonant'),
      6: ('', ('?',), 'punctuation mark'),
      7: ('', ('!',), 'punctuation mark'),
      8: ('', (',',), 'punctuation mark'),
      9: ('', ('3',), 'digit'),
      10: ('', ('0',), 'digit'),
      },
   'firstVowel':{
      1: ('', ('crystalline',), 'a'),
      2: ('', ('apple',), 'a'),
      3: ('', ('pineapple',), 'i'),
      4: ('', ('syrup',), 'u'),
      5: ('', ('rhythm',), ''),
      6: ('', ('z',), ''),
      },
   'firstVowelPosition':{
      1: ('', ('crystalline',), 5),
      2: ('', ('apple',), 0),
      3: ('', ('pineapple',), 1),
      4: ('', ('syrup',), 3),
      5: ('', ('rhythm',), -1),
      6: ('', ('z',), -1),
      },
   'translateWord':{
      1: ('', ('scram',), 'amscray'),
      2: ('', ('apple',), 'appleway'),
      3: ('', ('rhythm',), 'rhythmay'),
      4: ('', ('pancakes',), 'ancakespay'),
      5: ('', ('i',), 'iway'),
      6: ('', ('with',), 'ithway'),
      7: ('', ('house',), 'ousehay'),
      8: ('', ('pig',), 'igpay'),
      },
   'translateWord2':{
      # handles capitalization and punctuation
      1: ('', ('Apple',), 'Appleway'),
      2: ('', ('Rhythm',), 'Rhythmay'),
      3: ('', ('Scram',), 'Amscray'),
      4: ('', ('scram!',), 'amscray!'),
      5: ('', ('apple?',), 'appleway?'),
      6: ('', ('rhythm.',), 'rhythmay.'),
      7: ('', ('Scram!',), 'Amscray!'),
      8: ('', ('Apple?',), 'Appleway?'),
      9: ('', ('Rhythm.',), 'Rhythmay.'),
      10: ('', ('House,',), 'Ousehay,'),
      },
   'translateLine':{
      1: ('', ('scram',), 'amscray'),
      2: ('', ('got it',), 'otgay itway'),
      3: ('', ('the rain in spain',), 'ethay ainray inway ainspay'),
      4: ('', ('i scram with apple pancakes',), 'iway amscray ithway appleway ancakespay'),
      5: ('', ('',), ''),
      },
   'translateFile':{
      1: ('', ('haunting.txt',), None,
          'onay', 'ivelay', 'organismway', 'ancay', 'ontinuecay', 'orfay', 'onglay', 'otay',
          'existway', 'anelysay', 'underway', 'onditionscay', 'ofway', 'absoluteway', ('eality;ray', 'ealityray;'),
          'evenway', 'arkslay', 'andway', 'atydidskay', 'areway', ('upposed,say', 'upposedsay,'), 'byay',
          ('ome,say', 'omesay,'), 'otay', ('eam.dray', 'eamdray.'), 'illhay', ('ouse,hay', 'Ousehay,'),
          'otnay', ('ane,say', 'anesay,'), 'oodstay', 'byay', 'itselfway', 'againstway', 'itsway',
          ('ills,hay', 'illshay,'), 'oldinghay', 'arknessday', ('ithin;way', 'ithinway;'), 'itway', 'adhay',
          'oodstay', 'osay', 'orfay', 'eightyway', 'earsyay', 'andway', 'ightmay', 'andstay', 'orfay',
          'eightyway', ('ore.may', 'oremay.'), ('ithin,way', 'Ithinway,'), 'allsway', 'ontinuedcay',
          ('upright,way', 'uprightway,'), 'icksbray', 'etmay', ('eatly,nay', 'eatlynay,'), 'oorsflay',
          'ereway', ('irm,fay', 'irmfay,'), 'andway', 'oorsday', 'ereway', 'ensiblysay', ('ut;shay', 'utshay;'),
          'ilencesay', 'aylay', 'eadilystay', 'againstway', 'ethay', 'oodway', 'andway',
          'onestay', 'ofway', 'illhay', ('ouse,hay', 'ousehay,'), 'andway', 'ateverwhay',
          'alkedway', ('ere,thay', 'erethay,'), 'alkedway', ('alone.way', 'aloneway.')),
      # correct punctuation and capitalization
      2: ('', ('haunting.txt',), None,
          Lit('Onay ivelay organismway ancay ontinuecay orfay onglay otay existway'),
          Lit('anelysay underway onditionscay ofway absoluteway ealityray; evenway'),
          Lit('arkslay andway atydidskay areway upposedsay, byay omesay, otay'),
          Lit('eamdray. Illhay Ousehay, otnay anesay, oodstay byay itselfway'),
          Lit('againstway itsway illshay, oldinghay arknessday ithinway; itway adhay'),
          Lit('oodstay osay orfay eightyway earsyay andway ightmay andstay orfay'),
          Lit('eightyway oremay. Ithinway, allsway ontinuedcay uprightway,'),
          Lit('icksbray etmay eatlynay, oorsflay ereway irmfay, andway oorsday'),
          Lit('ereway ensiblysay utshay; ilencesay aylay eadilystay againstway'),
          Lit('ethay oodway andway onestay ofway Illhay Ousehay, andway ateverwhay'),
          Lit('alkedway erethay, alkedway aloneway.')),
      },
   'spell':{
      1: ('haunting2.txt', (), None,
          'wals unrecognized', 'agianst unrecognized', 'Howse unrecognized', 'wallked unrecognized'),
      },

}
